package com.tzld.piaoquan.risk.control.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.TypeReference;
import com.tzld.piaoquan.risk.control.common.base.CommonResponse;
import com.tzld.piaoquan.risk.control.config.QywxConfig;
import com.tzld.piaoquan.risk.control.model.po.UserBase;
import com.tzld.piaoquan.risk.control.model.qywx.LoginStatusResultModel;
import com.tzld.piaoquan.risk.control.model.qywx.QwCommonResModel;
import com.tzld.piaoquan.risk.control.model.qywx.QwLoginCheckCode;
import com.tzld.piaoquan.risk.control.model.qywx.QwLoginQRCodeModel;
import com.tzld.piaoquan.risk.control.service.QwLoginService;
import com.tzld.piaoquan.risk.control.service.qywx.Constant;
import com.tzld.piaoquan.risk.control.util.HttpClientUtil;
import com.tzld.piaoquan.risk.control.util.HttpPoolClient;
import com.tzld.piaoquan.risk.control.util.ImageUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.util.TextUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.bind.annotation.*;

import java.util.Base64;
import java.util.HashMap;
import java.util.Map;
import java.util.Optional;

@RestController
@RequestMapping("/qw")
@Slf4j
public class QwLoginController {
    private static final HttpPoolClient httpPoolClientDefault = HttpClientUtil.create(10000, 10000, 2000, 5000, 5, 10000);
    @Autowired
    private QywxConfig qywxConfig; // 注入配置类
    @Autowired
    private QwLoginService qwLoginService;
    private static final Logger LOGGER = LoggerFactory.getLogger(QwLoginController.class);


    @PostMapping("/getQrCode")
    public CommonResponse<QwLoginQRCodeModel> getQrCode(@RequestBody Map<String, String> request) {
        String vid = request.get("vid");
        LOGGER.info("getQrCode, vid: {}", vid);
        QwCommonResModel<QwLoginQRCodeModel> loginModel = qwLoginService.getLoginQRCode(vid);
        return CommonResponse.success(loginModel.getData());
    }

    @PostMapping("/checkQRCode")
    public CommonResponse<String> checkQRCode(@RequestBody QwLoginCheckCode checkCode) {
        int ret = qwLoginService.checkQRCode(checkCode);
        if(ret == 0) {
            return CommonResponse.success();
        } else {
            LOGGER.error("checkQRCode failed, ret: {}", ret);
            return CommonResponse.error("failed");
        }
    }

    @PostMapping("/secondaryValidation")
    public CommonResponse<QwLoginQRCodeModel> secondaryValidation(@RequestBody Map<String, String> request) {
        String uuid = request.get("uuid");
        QwCommonResModel<QwLoginQRCodeModel> loginModel = qwLoginService.secondaryValidation(uuid);
        if (loginModel != null && loginModel.getErrcode() == 0) {
            QwLoginQRCodeModel data = loginModel.getData();
            data.setUuid(uuid);

            String qrcodeUrl = data.getQrcode();
            if (StringUtils.isNotBlank(qrcodeUrl)) {
                try {
                    byte[] imageBytes = ImageUtils.downloadImage(qrcodeUrl);
                    String base64Image = Base64.getEncoder().encodeToString(imageBytes);
                    // 添加 Data URL 前缀，假设图片类型为 PNG
                    data.setQrcode_data(base64Image);
                } catch (Exception e) {
                    log.error("二维码下载或转换失败，URL: {}, 错误: {}", qrcodeUrl, e.getMessage());
                    return CommonResponse.error(null);
                }
            }

            return CommonResponse.success(data);
        } else {
            return CommonResponse.error(null);
        }
    }

    @PostMapping("/automaticLogin")
    public CommonResponse<String> automaticLogin(@RequestBody Map<String, String> request) {
        String uuid = request.get("uuid");
        boolean success = qwLoginService.automatedLogin(uuid);
        if (!success) {
            LOGGER.error("automaticLogin failed, uuid: {}", uuid);
            return CommonResponse.error("failed");
        } else {
            LOGGER.info("automaticLogin success, uuid: {}", uuid);
            return CommonResponse.success("success");
        }
    }

    @PostMapping("/quiteQwLogin")
    public CommonResponse<String> quiteQwLogin(@RequestBody Map<String, String> request) {
        String uuid = request.get("uuid");
        boolean isSuccess = qwLoginService.quitLogin(uuid);
        if (!isSuccess) {
            LOGGER.error("quiteQwLogin failed, uuid: {}", uuid);
            return CommonResponse.error("failed");
        } else {
            LOGGER.info("quiteQwLogin success, uuid: {}", uuid);
            return CommonResponse.success("success");
        }
    }

    @PostMapping("/checkLogin")//前端轮训检测是否登录成功
    public CommonResponse<LoginStatusResultModel> checkLogin(@RequestBody Map<String, String> request) {
        String uuid = request.get("uuid");
        UserBase user = qwLoginService.checkLogin(uuid);
        LoginStatusResultModel model = new LoginStatusResultModel();
        if (user != null && !TextUtils.isEmpty(user.getVid()) && user.getLoginStatus() == 1) {
            model.setLoginStatus(Constant.LOGIN_STATUS_LOGIN);
            model.setMessage("success");
            return CommonResponse.success(model);
        } else if (user != null && user.getLoginStatus() == Constant.LOGIN_STATUS_NO_LOGIN) {
            model.setLoginStatus(Constant.LOGIN_STATUS_NO_LOGIN);
            model.setMessage("processing");
            return CommonResponse.success(model);
        } else if(user != null && user.getLoginStatus() == Constant.LOGIN_STATUS_LOGIN_VERIFY) {
            model.setLoginStatus(Constant.LOGIN_STATUS_LOGIN_VERIFY);
            model.setMessage("输入验证码");
            return CommonResponse.success(model);
        }else {
            model.setLoginStatus(Constant.LOGIN_STATUS_LOGIN_FAIL);
            model.setMessage("failed");
            return CommonResponse.success(model);
        }
    }
    @PostMapping("/getRunClients")//获取运行中的实例
    public CommonResponse<String> getRunClients() {
        return CommonResponse.success(qwLoginService.getRunClients());
    }

}
